@@ -12,6 +12,7 @@ import json
 import logging
 import math
 import re
+import traceback
 import urllib.parse
 
 import tornado.web
@@ -29,7 +30,7 @@ from utils import Redis
 class BaseHandler(tornado.web.RequestHandler):
 
     def __init__(self, application, request, **kwargs):
-        super().__init__(application, request)
+        super().__init__(application, request, **kwargs)
         self.logger = logging
         self.ua = self.request.headers.get('User-Agent', '')
         self.referer = self.request.headers.get('Referer', '')
@@ -77,13 +78,13 @@ class BaseHandler(tornado.web.RequestHandler):
                 return True
 
         if raise_error:
-            self.logger.warning(f'unauthorized domains: {domains}, referer: {self.referer}')
+            self.logger.warning(f'authorized domains: {domains}, referer: {self.referer}')
             raise tornado.web.HTTPError(403)
         else:
             return False
 
     async def get_current_user(self):
-        token = self.get_cookie('user_token', self.args.token)
+        token = self.get_cookie('token', self.args.token)
         if token:
             if hasattr(self.app, 'rd') and isinstance(self.app.rd, (Redis, AioRedis)):
                 user = await awaitable(self.app.rd.get(f'{self.prefix}_token_{token}'))
@@ -134,9 +135,9 @@ class BaseHandler(tornado.web.RequestHandler):
         return super().write(chunk)
 
     def write_error(self, status_code, **kwargs):
-        # if kwargs.get('exc_info'):
-        #     msg = ''.join(traceback.format_exception(*kwargs["exc_info"]))
-        #     self.logger.error(msg)
+        if self.application.settings.get('debug') and kwargs.get('exc_info'):
+            msg = ''.join(traceback.format_exception(*kwargs["exc_info"]))
+            self.logger.error(msg)
         super().write_error(status_code, **kwargs)
 
     def render(self, template_name, **kwargs):
