@@ -98,7 +98,7 @@ class BaseHandler(BaseHandler):
             elif self.current_user and self.current_user._id != user._id:
                 return {'err': 2, 'msg': f'该微信号已绑定用户{user.id}'}
             expires = datetime.datetime.now() + datetime.timedelta(days=30)
-            self.set_cookie('user_token', user.token, expires=expires)
+            self.set_cookie('token', user.token, expires=expires)
             ret.err = 0
 
         return ret
@@ -121,8 +121,8 @@ class CheckHandler(BaseHandler):
 class LogoutHandler(BaseHandler):
 
     def get(self):
+        self.clear_cookie('token')
         self.clear_cookie('user_token')
-        self.clear_cookie('user_info')
         self.redirect('/')
 
 
@@ -159,7 +159,7 @@ class SignupHandler(BaseHandler):
                 'created_at': datetime.datetime.now().replace(microsecond=0)
             })
             await awaitable(self.db.users.insert_one(doc))
-            self.set_cookie('user_token', token, expires_days=30)
+            self.set_cookie('token', token, expires_days=30)
             self.finish({'err': 0})
             # await self.app.http.get(f'https://{self.request.host}/email/active', params={'email': email})
         else:
@@ -186,9 +186,9 @@ class SigninHandler(BaseHandler):
             if user:
                 ret = {'err': 0, 'msg': '登录成功'}
                 if remember == 'on':
-                    self.set_cookie('user_token', user.token, expires_days=30)
+                    self.set_cookie('token', user.token, expires_days=30)
                 else:
-                    self.set_cookie('user_token', user.token)
+                    self.set_cookie('token', user.token)
             else:
                 ret = {'err': 1, 'msg': '用户名或密码错误'}
         else:
