@@ -14,6 +14,7 @@ import json
 import math
 import queue
 import socket
+import sys
 import threading
 import time
 from pathlib import Path
@@ -65,6 +66,7 @@ class tqdm(tqdm):
     def __init__(self, *args, **kwargs):
         if args and isinstance(args[0], Cursor):
             kwargs.setdefault('total', args[0].count())
+        kwargs.setdefault('disable', not sys.stdout.isatty())
         super().__init__(*args, **kwargs)
 
     def update(self, n=None, total=None, incr=None):
@@ -124,8 +126,8 @@ def get_ip(local=True):
             s.close()
     else:
         try:
-            resp = requests.get('https://api.ishield.cn/ip', timeout=3)
-            return resp.text
+            resp = requests.get('http://ddns.oray.com/checkip', timeout=3)
+            return resp.text.split()[-1]
         except Exception:
             return '127.0.0.1'
 
